Connect

Function Connect 

#[unsafe(no_mangle)]
pub extern "C" fn Connect(_com: *mut c_char) -> i32
Open serial port and setup security channel with R/W

Parameters

  • com: Name of COM port, e.g. “/dev/ttyS0” (unused in mock implementation)

Returns

  • 0: Communication with R/W succeeded
  • -1: Cannot open COM
  • -2: Communication error with R/W

Safety

This function is safe to call from C code.